@@ -682,7 +682,7 @@ void Board::paintEvent(QPaintEvent * e)
     if (m_paintPossibleMoves) {
         p.setPen(QPen(QColor("blue"), lineWidth()));
         // paint all possible moves
-        for (auto const &move : qAsConst(m_possibleMoves)) {
+        for (auto const &move : std::as_const(m_possibleMoves)) {
             auto pt1 = move.path().cbegin();
             auto pt2 = pt1 + 1;
             while (pt2 != move.path().cend()) {
@@ -885,7 +885,7 @@ void Board::marked(TilePos tilePos)
 {
     if (field(tilePos) == EMPTY) { // click on empty space on the board
         if (m_possibleMoves.size() > 1) { // if the click is on any of the current possible moves, make that move
-            for (auto move : qAsConst(m_possibleMoves)) {
+            for (auto move : std::as_const(m_possibleMoves)) {
                 if (move.isInPath(tilePos)) {
                     performMove(move);
                     Q_EMIT selectATile();
@@ -923,7 +923,7 @@ void Board::marked(TilePos tilePos)
     }
     if (m_possibleMoves.size() > 1) { // if the click is on any of the current possible moves, make that move
 
-        for (auto move : qAsConst(m_possibleMoves)) {
+        for (auto move : std::as_const(m_possibleMoves)) {
             if (move.isInPath(tilePos)) {
                 performMove(move);
                 Q_EMIT selectATile();
@@ -946,7 +946,7 @@ void Board::marked(TilePos tilePos)
     if (findPath(TilePos(m_markX, m_markY), tilePos, m_possibleMoves) > 0) {
         if (m_possibleMoves.size() > 1) {
             auto withSlide = 0;
-            for (auto const &move : qAsConst(m_possibleMoves)) {
+            for (auto const &move : std::as_const(m_possibleMoves)) {
                 move.Debug();
                 if (move.hasSlide()) {
                     ++withSlide;
